function circularBuffer = circular_buffer_add(circularBuffer, newValues)
% circularBuffer = circular_buffer_add(circularBuffer, newValues)
% values must be channels  x number of frames


% expand buffer dimensions if new values have larger number of channels,
% values for previous data are filled will zeros for new channels
if size(newValues, 1) > size(circularBuffer.buffer, 1)
    circularBuffer.buffer(size(circularBuffer.buffer, 1)+1:size(newValues, 1), :) = 0;
    fprintf('Buffer channels expanded to %d in order to accomodate newly added values.\n', size(circularBuffer.buffer, 1));
end;

newValueLength = size(newValues, 2);

% prevent multiple wrap-around if new values have a large length than
% buffer
if newValueLength > circularBuffer.length-1 % the actual capacity of buffer is circularBuffer.length because of one unused location between start and end
    % cut new value size to fit in the buffer
    newValues = newValues(:, (end-circularBuffer.length + 2):end);
    newValueLength = size(newValues, 2);
end;

if newValueLength <= (circularBuffer.length  - circularBuffer.endId)
    
    % single straight block in buffer
    if newValueLength == 1
        circularBuffer.buffer(:, circularBuffer.endId + 1) = newValues;
    else
        circularBuffer.buffer(:, (circularBuffer.endId + 1):(circularBuffer.endId + newValueLength)) = newValues;
    end;
    
    circularBuffer.endId = circularBuffer.endId + newValueLength;
    
    if circularBuffer.isFull
        circularBuffer.startId = circularBuffer.endId + 2; % there should always be an empty location between start and end
        if circularBuffer.startId > circularBuffer.length
            circularBuffer.startId = circularBuffer.startId - circularBuffer.length;
        end;
    end;
    
else % wrap around
    bufferSegmentUntilEnd = (circularBuffer.endId + 1):circularBuffer.length;
    bufferSegmentFromBeginning = 1:(newValueLength - length(bufferSegmentUntilEnd));
    
    circularBuffer.buffer(:, bufferSegmentUntilEnd) = newValues(:, 1:length(bufferSegmentUntilEnd));
    circularBuffer.buffer(:, bufferSegmentFromBeginning) = newValues(:, length(bufferSegmentUntilEnd)+1:end);
    
    circularBuffer.endId = length(bufferSegmentFromBeginning);
    
    if circularBuffer.endId >= circularBuffer.startId
        circularBuffer.startId = circularBuffer.endId + 2; % there should always be an empty location between start and end
        if circularBuffer.startId > circularBuffer.length
            circularBuffer.startId = circularBuffer.startId - circularBuffer.length;
        end;
        circularBuffer.isFull = true;
    end;
    
end;



