function mr_accumulate_events(doReset)
% read events from an event channel and place them in mr.event field
% Each event in mr.event structure has three fields: Type, Latency (in frames) and Triggered. The latter indicates whether the event has already triggered a callback function. 
% mr.eventChannelNumber should contain the event channel number

global mr
persistent eventLatencies

if nargin>0 && doReset
    mr.event = [];
    eventLatencies = [];
    return;
end;


numberOfPastFramesToLookForEventsIn = mr.samplingRate * 2; % look in the last 2 s of data
if mr.numberOfFramesInAccumulatedData > numberOfPastFramesToLookForEventsIn
    
    
    % look for events in the last numberOfPastFramesToLookForEventsIn frames,
    % first get the event channel values in that period
    eventChannelData = mr.accumulatedData(mr.eventChannelNumber, (mr.numberOfFramesInAccumulatedData - numberOfPastFramesToLookForEventsIn):mr.numberOfFramesInAccumulatedData);
    
    % detect events (when a value changes to some non-zero value), prevent
    % duplicates by comparing to past event latencies and add them to
    % mr.event
    
    eventCounter = length(mr.event) + 1;
    
    for i=2:numel(eventChannelData)
        if eventChannelData(i)~=0 && (eventChannelData(i) ~= eventChannelData(i-1))
            eventLatency = i + mr.numberOfFramesReceived - numberOfPastFramesToLookForEventsIn - 1;
            if ~any(eventLatencies == eventLatency)
                mr.event(eventCounter).type = eventChannelData(i)
                mr.event(eventCounter).latency = eventLatency;
                mr.event(eventCounter).triggered = false;
                eventLatencies = [eventLatencies eventLatency];
                eventCounter = eventCounter + 1;
            end;
        end;
    end;
    
end;
