function mr_close_write_buffer(bufferName)
% close all write buffers if no buffername is given

global mr;

% exist if the field mr.write does not exist at all (which means there
% are no write buffers to close)
if ~isfield(mr, 'read') 
    return;
end;

if nargin<1 % close all write buffers if no buffername is given
    for i=1:length(mr.write.BufferHandle)
        ds_CloseWrite(mr.write.BufferHandle{i})
    end;
    
    % clear all buffers
    mr.write.bufferName = {};
    mr.write.bufferSamplingRate = [];
    mr.write.bufferHandle = [];
    
    if mr.verboseLevel > 0
        fprintf('All DataRiver write buffer handles are closed and deleted.\n');
    end;
else
    bufferId = find(strcmp(mr.write.bufferName, bufferName));
    
    if ~isempty(bufferId)
        ds_CloseWrite(mr.write.bufferHandle{bufferId});
        
        % remove buffer index
        mr.write.bufferName(bufferId) = [];
        mr.write.bufferSamplingRate(bufferId) = [];
        mr.write.bufferHandle(bufferId) = [];
        
        if mr.verboseLevel > 0
            fprintf('DataRiver write buffer ''%s'' is closed and deleted.\n', bufferName);
        end;
    else % no buffer with tha name existed
        if mr.verboseLevel > 0
            fprintf('No buffer with the name ''%s'' exited.\n', bufferName);
        end;
    end;
    
    
end;

