function mr_event_trigger
% goes through events in mr.event and triggers callback functions for the event when necessary. Each trigger is defined by the types of events and the duration of time after these for which the callback has to be executed. For example, a trigger can launch a classifier after 800 ms has passed after events of type 1 or 2.  
% Triggers are placed in mr.trigger field, which is an array of an structure with two fields:
%
%     eventType: (numeric) type of a (single) trigger event.
%     timeAfter: (numeric) time in ms after which the trigger should fire.
%     callback: function (handle) to be executed when trigger fires. This callback function should have at least one input parameter for eventNumber, which is passed to it during trigger execution. 

global mr
 
numberOfLastEventsToCheck = 100;

if isfield(mr, 'trigger')
    
    triggeringEventType = [];
    triggeringEventRequiredDataAfter = [];
    clear triggeringEventCallback;
    
    for i=1:length(mr.trigger)
        triggeringEventType(i) = mr.trigger(i).eventType;
        triggeringEventRequiredDataAfter(i) = mr.trigger(i).timeAfter; % in ms
        triggeringEventCallback{i} = mr.trigger(i).callback;
    end;
else
    return; % no triggers are defined since the field does not exist
end;

% turn ms into frames
triggeringEventRequiredFramesAfter = triggeringEventRequiredDataAfter * mr.samplingRate / 1000;

for eventNumber=max(length(mr.event) - numberOfLastEventsToCheck, 1):length(mr.event)
    triggeringEventTypeId = find(triggeringEventType == mr.event(eventNumber).type);
    if ~isempty(triggeringEventTypeId) && ~mr.event(eventNumber).triggered &&  (mr.numberOfFramesReceived - mr.event(eventNumber).latency > triggeringEventRequiredFramesAfter(triggeringEventTypeId))        
        mr.event(eventNumber).triggered = true;
        
        % execute the callback, provide event number to it too.
        if ~isempty(triggeringEventCallback{triggeringEventTypeId})
            triggeringEventCallback{triggeringEventTypeId}(eventNumber);
        end;
    end;        
end;
