function numberOfNewIcaFrames = mr_raw_to_ic_activity_accumulate(doReset)
% calculate activity of select ICs from its last execution until the
% latest received data frame and place it in mr.eeg.accumulatedIcActivity field, which is a circular buffer.

if nargin<1
    doReset = false;
end;

numberOfNewIcaFrames = 0;

global mr
persistent lastFrameNumberForWhichICActivityisCalculated highpassFilterDelay lowpassFilterDelay iirFilter

if isempty(lastFrameNumberForWhichICActivityisCalculated) || doReset
    lastFrameNumberForWhichICActivityisCalculated = 0;
    mr.eeg.accumulatedIcActivity = [];
    
    % IIR filter design, only highpass for now, since bandpass IR is more
    % complicated
    nyq = mr.samplingRate * 0.5;  % Nyquist frequency
    
    
    if ~isempty(mr.eeg.locutoff) % for highpass
        filterOrder = 2;
        wn = mr.eeg.locutoff / nyq;
        [iirFilter.highpass.b, iirFilter.highpass.a]= butter(filterOrder,wn,'high');
    end;
    
    if ~isempty(mr.eeg.hicutoff) % for lowpass
        filterOrder = 3;
        wn = mr.eeg.hicutoff / nyq;
        [iirFilter.lowpass.b, iirFilter.lowpass.a]= butter(filterOrder,wn,'low');
    end;
    
    highpassFilterDelay = []; % zf and zi for filter()
    lowpassFilterDelay = []; % zf and zi for filter()
end;

numberOfFrameToCalculateICActivityFor = mr.numberOfFramesReceived - lastFrameNumberForWhichICActivityisCalculated;
accumulatedDataframes = (mr.numberOfFramesInAccumulatedData - numberOfFrameToCalculateICActivityFor + 1) : mr.numberOfFramesInAccumulatedData;


% extract eeg channel data (or subset of EEG channels) from all channels
% (which may contain mocap, event or other data too)

if mr.numberOfFramesInAccumulatedData == 0
    mr.eeg.icActivity = [];
    return;
else % reference channel is either a number, or the string 'average'
    if mr.eeg.reference_is_included
        % means that the reference channel index is relative to channel subset indices
        eegData = channel_subset_and_re_reference_to_included_reference(mr, accumulatedDataframes);
    else
        % means that the reference channel index is relative to original
        % (all) accumulated channel data
        eegData = channel_subset_and_re_reference_to_non_included_reference(mr, accumulatedDataframes);
    end;
end;



% filetr channel data with IIR
if ~isempty(mr.eeg.locutoff) && ~isempty(eegData)
    [eegData highpassFilterDelay] = filter(iirFilter.highpass.b, iirFilter.highpass.a, eegData, highpassFilterDelay,2);
end;


if ~isempty(mr.eeg.hicutoff) && ~isempty(eegData)
    [eegData lowpassFilterDelay] = filter(iirFilter.lowpass.b, iirFilter.lowpass.a, eegData, lowpassFilterDelay,2);
end;


% calculate activity of request ICs (generally only a subset of IC activities are calclated to save execution time)
newIcActivity = mr.eeg.activeIcaUnmix(mr.eeg.icNumbersToCalculateActivity, :) * eegData;


if ~isfield(mr.eeg, 'accumulatedIcActivity') || isempty(mr.eeg.accumulatedIcActivity)
    % create the buffer if empty or not defined
    mr.eeg.accumulatedIcActivity = circular_buffer_init( 5000 , size(newIcActivity, 1)); 
end;

%mr.eeg.accumulatedIcActivity = cat(2,mr.eeg.accumulatedIcActivity, newIcActivity);
mr.eeg.accumulatedIcActivity = circular_buffer_add(mr.eeg.accumulatedIcActivity, newIcActivity);

% return the number of newly calculated ICA frames (usefil for write
% buffers, for example)
numberOfNewIcaFrames = size(newIcActivity, 2);

lastFrameNumberForWhichICActivityisCalculated = mr.numberOfFramesReceived;

% highpass and lowpass filtering of ic activty
%mr.eeg.icActivity = eegfiltfft(mr.eeg.icActivity, mr.samplingRate, mr.eeg.locutoff, mr.eeg.hicutoff);


end

