% In this tutorial we read data in a simulated realtime
% manner and calculate the activity of an ICA component. This activity is
% accumulated and segmented into 900 ms portions after certain events using
% MatRiver triggers.

% load mr structure prepared for this tutorial
load tutorial_mr_structure.mat;

mr_init;

%mr.eeg.channelOffset = 0;

% define ic number to calculate activity for
mr.eeg.icNumbersToCalculateActivity = 17;


% define event triggers
mr.trigger = [];
mr.trigger(1).eventType = 1;
mr.trigger(1).timeAfter = 900; % ms
mr.trigger(1).callback = @image_display_callback;

mr.trigger(2).eventType = 2;
mr.trigger(2).timeAfter = 900; % ms
mr.trigger(2).callback = @image_display_callback;


% reset the state of the function that send simulated data, this is
% necessary before starting the timer.
mr_read_simulated(true); 

% initiate execution lag calculation
mr_record_lag(true);

% delete all timers;
delete(timerfindall);

% define and then start the main MatRiver timer
if isempty(timerfind('tag','accumulatorTimer'))
    
    % this timer executes certain commands (specified after 'TimerFcn' key)
    % each 0.1 seconds. It does not block the command line so you can still
    % examine the variables and work with matlab while MatRiver is running.
    accumulatorTimer = timer('TimerFcn','mr_accumulate;mr_detect_bad_channels; mr_update_ica;mr_raw_to_ic_activity_accumulate;mr_accumulate_events;mr_event_trigger;mr_record_lag','StartDelay',0,'ExecutionMode','fixedSpacing','Period',0.1,'tag','accumulatorTimer');   
    
    % start the timer
    start(accumulatorTimer);
end;